"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var nativescript_mpchart_common_1 = require("../nativescript-mpchart.common");
var color_1 = require("tns-core-modules/color");
var application = require("tns-core-modules/application");
var formatNumber = require("simple-format-number");
var BarChart = com.github.mikephil.charting.charts.BarChart;
var BarDataSet = com.github.mikephil.charting.data.BarDataSet;
var BarData = com.github.mikephil.charting.data.BarData;
var BarEntry = com.github.mikephil.charting.data.BarEntry;
var ArrayList = java.util.ArrayList;
var XAxis = com.github.mikephil.charting.components.XAxis;
var IndexAxisValueFormatter = com.github.mikephil.charting.formatter.IndexAxisValueFormatter;
var DefaultValueFormatter = com.github.mikephil.charting.formatter.DefaultValueFormatter;
var IAxisValueFormatter = com.github.mikephil.charting.formatter.IAxisValueFormatter;
var Description = com.github.mikephil.charting.components.Description;
var IValueFormatter = com.github.mikephil.charting.formatter.IValueFormatter;
var MPBarChart = (function (_super) {
    __extends(MPBarChart, _super);
    function MPBarChart() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MPBarChart.prototype.resetZoomLineChart = function () {
        this.nativeView.resetZoom();
    };
    MPBarChart.prototype.createNativeView = function () {
        var barChartView = new BarChart(this._context);
        var xAxis = barChartView.getXAxis();
        var yAxisLeft = barChartView.getAxisLeft();
        var yAxisRight = barChartView.getAxisRight();
        xAxis.setDrawGridLines(false);
        yAxisLeft.setDrawGridLines(false);
        yAxisRight.setDrawGridLines(false);
        xAxis.setGranularity(1);
        xAxis.setDrawGridLines(false);
        yAxisLeft.setDrawGridLines(false);
        yAxisRight.setDrawGridLines(false);
        xAxis.setAxisMinimum(0);
        yAxisLeft.setAxisMinimum(0);
        yAxisRight.setAxisMinimum(0);
        yAxisLeft.setDrawLabels(true);
        yAxisRight.setDrawLabels(true);
        yAxisLeft.setEnabled(true);
        yAxisRight.setEnabled(true);
        var description = new Description();
        description.setText("");
        barChartView.setDescription(description);
        barChartView.setDoubleTapToZoomEnabled(false);
        barChartView.setFitBars(true);
        barChartView.setScaleEnabled(false);
        return barChartView;
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.itemsProperty.setNative] = function (items) {
        var barDatasets = new ArrayList();
        for (var i = 0; i < items.length; i++) {
            if (items[i].dataSet && items[i].dataSet.length) {
                var labelLegend = items[i].legendLabel ? items[i].legendLabel : "";
                var entries = [];
                for (var j = 0; j < items[i].dataSet.length; j++) {
                    var entrie = new BarEntry(items[i].dataSet[j].x, items[i].dataSet[j].y);
                    entries.push(entrie);
                }
                if (entries.length) {
                    var dataset = new BarDataSet(new ArrayList(java.util.Arrays.asList(entries)), labelLegend);
                    dataset.setColor(items[i].barColor.android);
                    if (items[i].highlighColor) {
                        dataset.setHighLightColor(items[i].highlighColor.android);
                    }
                    if (this.showValueLabels != undefined) {
                        dataset.setDrawValues(this.showValueLabels);
                    }
                    else {
                        dataset.setDrawValues(true);
                    }
                    barDatasets.add(dataset);
                }
            }
            else {
                throw new Error("items number " + i + "do not have any item");
            }
        }
        var barChartData = new BarData(barDatasets);
        this.nativeView.setData(barChartData);
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.labelsProperty.setNative] = function (labels) {
        var self = this;
        if (labels) {
            if (this.nativeView.getXAxis()) {
                this.nativeView.getXAxis().setValueFormatter(new IAxisValueFormatter({
                    getFormattedValue: function (value, entry) {
                        for (var i = 0; i < labels.length; i++) {
                            if (labels[i].xAxisValue == value) {
                                return labels[i].label + '';
                            }
                        }
                        return "";
                    }
                }));
            }
            else {
                throw new Error("xAxis in labels Property setup undefined");
            }
        }
        else {
            throw new Error("labels value undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.showLegendProperty.setNative] = function (value) {
        var legend = this.nativeView.getLegend();
        console.log("showLegend ", value);
        if (legend) {
            legend.setEnabled(value);
        }
        else {
            throw new Error("Property 'legend' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.showGridLinesProperty.setNative] = function (value) {
        var xAxis;
        var leftAxis;
        var rightAxis;
        xAxis = this.nativeView.getXAxis();
        leftAxis = this.nativeView.getAxisLeft();
        rightAxis = this.nativeView.getAxisRight();
        if (xAxis && leftAxis && rightAxis) {
            xAxis.setDrawGridLines(value);
            leftAxis.setDrawGridLines(value);
            rightAxis.setDrawGridLines(value);
        }
        else {
            throw new Error("Property 'xAxis' or 'leftAxis' or 'rightAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.scaleEnableProperty.setNative] = function (value) {
        this.nativeView.setScaleEnabled(value);
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.descriptionTextProperty.setNative] = function (value) {
        var chartDescription = this.nativeView.getDescription().setText(value);
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.descriptionXOffsetProperty.setNative] = function (value) {
        this.nativeView.getDescription().setXOffset(value);
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.descriptionYOffsetProperty.setNative] = function (value) {
        this.nativeView.getDescription().setYOffset(value);
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.descriptionTextColorProperty.setNative] = function (value) {
        this.nativeView.getDescription().setTextColor(value.android);
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.descriptionTextColorCssProperty.setNative] = function (value) {
        this.nativeView.getDescription().setTextColor(value.android);
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.highlightPerTapEnabledProperty.setNative] = function (value) {
        this.nativeView.setHighlightPerTapEnabled(value);
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.highlightPerDragEnabledProperty.setNative] = function (value) {
        this.nativeView.setHighlightPerDragEnabled(value);
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.xAxisGranularityProperty.setNative] = function (value) {
        if (this.nativeView.getXAxis()) {
            this.nativeView.getXAxis().setGranularity(value);
        }
        else {
            throw new Error("Property 'xAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.leftAxisGranularityProperty.setNative] = function (value) {
        if (this.nativeView.getAxisLeft()) {
            this.nativeView.getAxisLeft().setGranularity(value);
        }
        else {
            throw new Error("Property 'leftAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.rightAxisGranularityProperty.setNative] = function (value) {
        if (this.nativeView.getAxisRight()) {
            this.nativeView.getAxisRight().setGranularity(value);
        }
        else {
            throw new Error("Property 'rightAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.xAxisLabelPositionProperty.getDefault] = function () {
        return "Bottom";
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.xAxisLabelPositionProperty.setNative] = function (value) {
        var xAxis = this.nativeView.getXAxis();
        if (xAxis) {
            switch (value) {
                case "Top":
                    this.nativeView.getXAxis().setPosition(XAxis.XAxisPosition.TOP);
                    break;
                case "Bottom":
                    this.nativeView.getXAxis().setPosition(XAxis.XAxisPosition.BOTTOM);
                    break;
                case "BothSided":
                    this.nativeView.getXAxis().setPosition(XAxis.XAxisPosition.BOTH_SIDED);
                    break;
                case "TopInside":
                    this.nativeView.getXAxis().setPosition(XAxis.XAxisPosition.TOP_INSIDE);
                    break;
                case "BottomInside":
                    this.nativeView.getXAxis().setPosition(XAxis.XAxisPosition.BOTTOM_INSIDE);
                    break;
                default:
                    console.log("Value of xAxisLabelPosition property do not exist, default value will set Bottom");
                    break;
            }
        }
        else {
            throw new Error("Property 'xAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.xAxisLineColorProperty.setNative] = function (value) {
        var xAxis;
        xAxis = this.nativeView.getXAxis();
        if (xAxis && value) {
            xAxis.setAxisLineColor(value.android);
        }
        else {
            throw new Error("Property  'xAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.xAxisLineColorCssProperty.setNative] = function (value) {
        var xAxis;
        xAxis = this.nativeView.getXAxis();
        if (xAxis && value) {
            xAxis.setAxisLineColor(value.android);
        }
        else {
            throw new Error("Property  'xAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.leftAxisLineColorProperty.setNative] = function (value) {
        var leftAxis;
        leftAxis = this.nativeView.getAxisLeft();
        if (leftAxis && value) {
            leftAxis.setAxisLineColor(value.android);
        }
        else {
            throw new Error("Property  'leftAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.leftAxisLineColorCssProperty.setNative] = function (value) {
        var leftAxis;
        leftAxis = this.nativeView.getAxisLeft();
        if (leftAxis && value) {
            leftAxis.setAxisLineColor(value.android);
        }
        else {
            throw new Error("Property  'leftAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.rightAxisLineColorProperty.setNative] = function (value) {
        var rightAxis;
        rightAxis = this.nativeView.getAxisRight();
        if (rightAxis && value) {
            rightAxis.setAxisLineColor(value.android);
        }
        else {
            throw new Error("Property  'rightAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.rightAxisLineColorCssProperty.setNative] = function (value) {
        var rightAxis;
        rightAxis = this.nativeView.getAxisRight();
        if (rightAxis && value) {
            rightAxis.setAxisLineColor(value.android);
        }
        else {
            throw new Error("Property  'rightAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.xAxisTextColorProperty.setNative] = function (value) {
        var xAxis;
        xAxis = this.nativeView.getXAxis();
        if (xAxis && value) {
            xAxis.setTextColor(value.android);
        }
        else {
            throw new Error("Property  'xAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.xAxisTextColorCssProperty.setNative] = function (value) {
        var xAxis;
        xAxis = this.nativeView.getXAxis();
        if (xAxis && value) {
            xAxis.setTextColor(value.android);
        }
        else {
            throw new Error("Property  'xAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.leftAxisTextColorProperty.setNative] = function (value) {
        var leftAxis;
        leftAxis = this.nativeView.getAxisLeft();
        if (leftAxis && value) {
            leftAxis.setTextColor(value.android);
        }
        else {
            throw new Error("Property  'leftAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.leftAxisTextColorCssProperty.setNative] = function (value) {
        var leftAxis;
        leftAxis = this.nativeView.getAxisLeft();
        if (leftAxis && value) {
            leftAxis.setTextColor(value.android);
        }
        else {
            throw new Error("Property  'leftAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.rightAxisTextColorProperty.setNative] = function (value) {
        var rightAxis;
        rightAxis = this.nativeView.getAxisRight();
        if (rightAxis && value) {
            rightAxis.setTextColor(value.android);
        }
        else {
            throw new Error("Property  'rightAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.rightAxisTextColorCssProperty.setNative] = function (value) {
        var rightAxis;
        rightAxis = this.nativeView.getAxisRight();
        if (rightAxis && value) {
            rightAxis.setTextColor(value.android);
        }
        else {
            throw new Error("Property  'rightAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.xAxisMinValueProperty.setNative] = function (value) {
        var xAxis;
        xAxis = this.nativeView.getXAxis();
        if (xAxis) {
            console.log("xAxisMinValueProperty ", value);
            xAxis.setAxisMinimum(value);
        }
        else {
            throw new Error("Property  'xAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.xAxisMaxValueProperty.setNative] = function (value) {
        var xAxis;
        xAxis = this.nativeView.getXAxis();
        if (xAxis) {
            console.log("xAxisMinValueProperty ", value);
            xAxis.setAxisMaximum(value);
        }
        else {
            throw new Error("Property  'xAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.leftAxisMinValueProperty.setNative] = function (value) {
        var leftAxis;
        leftAxis = this.nativeView.getAxisLeft();
        if (leftAxis) {
            leftAxis.setAxisMinimum(value);
        }
        else {
            throw new Error("Property  'leftAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.leftAxisMaxValueProperty.setNative] = function (value) {
        var leftAxis;
        leftAxis = this.nativeView.getAxisLeft();
        if (leftAxis) {
            leftAxis.setAxisMaximum(value);
        }
        else {
            throw new Error("Property  'leftAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.leftAxisMaxValueProperty.setNative] = function (value) {
        var rightAxis;
        rightAxis = this.nativeView.getAxisRight();
        if (rightAxis) {
            rightAxis.setAxisMinimum(value);
        }
        else {
            throw new Error("Property  'rightAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.rightAxisMaxValueProperty.setNative] = function (value) {
        var rightAxis;
        rightAxis = this.nativeView.getAxisRight();
        if (rightAxis) {
            rightAxis.setAxisMaximum(value);
        }
        else {
            throw new Error("Property  'rightAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.leftAxisFormatterProperty.setNative] = function (formatterValue) {
        if (formatterValue) {
            var leftAxis = this.nativeView.getAxisLeft();
            var formatter = void 0;
            switch (formatterValue.type) {
                case "Int":
                    formatter = new IAxisValueFormatter({
                        getFormattedValue: function (value, entry) {
                            if (value == 0 || value) {
                                return value.toFixed();
                            }
                            else {
                                return "";
                            }
                        }
                    });
                    leftAxis.setValueFormatter(formatter);
                    break;
                case "Float":
                    formatter = new IAxisValueFormatter({
                        getFormattedValue: function (value, entry) {
                            if (value == 0 || value) {
                                return value.toFixed(formatterValue.numberOfDigits);
                            }
                            else {
                                return "";
                            }
                        }
                    });
                    leftAxis.setValueFormatter(formatter);
                    break;
                default:
                    break;
            }
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.rightAxisFormatterProperty.setNative] = function (formatterValue) {
        if (formatterValue) {
            var rightAxis = this.nativeView.getAxisRight();
            var formatter = void 0;
            switch (formatterValue.type) {
                case "Int":
                    formatter = new IAxisValueFormatter({
                        getFormattedValue: function (value, entry) {
                            if (value == 0 || value) {
                                return value.toFixed();
                            }
                            else {
                                return "";
                            }
                        }
                    });
                    rightAxis.setValueFormatter(formatter);
                    break;
                case "Float":
                    formatter = new IAxisValueFormatter({
                        getFormattedValue: function (value, entry) {
                            if (value == 0 || value) {
                                return value.toFixed(formatterValue.numberOfDigits);
                            }
                            else {
                                return "";
                            }
                        }
                    });
                    rightAxis.setValueFormatter(formatter);
                    break;
                default:
                    break;
            }
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.showValueLabelsProperty.getDefault] = function () {
        return true;
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.showValueLabelsProperty.setNative] = function (value) {
        this.showValueLabels = value;
        if (this.nativeView.getData()) {
            var dataSets = this.nativeView.getData().getDataSets();
            if (dataSets) {
                for (var i = 0; i < dataSets.size(); i++) {
                    this.nativeView.getData().getDataSets().get(i).setDrawValues(value);
                }
            }
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.showLeftAxisProperty.setNative] = function (value) {
        var leftAxis;
        leftAxis = this.nativeView.getAxisLeft();
        if (leftAxis) {
            leftAxis.setEnabled(value);
        }
        else {
            throw new Error("Property  'xAxis' in showLeftAxisProperty of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.showRightAxisProperty.setNative] = function (value) {
        var rightAxis;
        rightAxis = this.nativeView.getAxisRight();
        if (rightAxis) {
            rightAxis.setEnabled(value);
        }
        else {
            throw new Error("Property  'xAxis' in showRightAxisProperty of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.markerProperty.setNative] = function (markerConfig) {
        console.log("markerProperty");
        var marker = new CustomChartMarkerView(this._context, null);
        marker.setConfig(markerConfig);
        this.nativeView.setMarker(marker);
    };
    return MPBarChart;
}(nativescript_mpchart_common_1.MPChartBase));
exports.MPBarChart = MPBarChart;
var CustomChartMarkerView = (function (_super) {
    __extends(CustomChartMarkerView, _super);
    function CustomChartMarkerView(context, layoutResource) {
        var _this = this;
        var resourceLayout;
        var getPackageName = function () {
            var packageName = application.android.packageName;
            var arrSplitPackageName = [];
            arrSplitPackageName = packageName.split(".");
            var appResourceObject = global;
            for (var i = 0; i < arrSplitPackageName.length; i++) {
                appResourceObject = appResourceObject[arrSplitPackageName[i]];
            }
            if (appResourceObject == global) {
                throw new Error("Undefined package name R object");
            }
            return appResourceObject;
        };
        if (layoutResource) {
            resourceLayout = layoutResource;
        }
        else {
            var packageName = getPackageName();
            resourceLayout = packageName.R.layout.default_marker_view;
        }
        _this = _super.call(this, context, resourceLayout) || this;
        _this.packageName = getPackageName();
        _this.context = context;
        _this.setDefault();
        return _this;
    }
    CustomChartMarkerView.prototype.refreshContent = function (entry, highlight) {
        this.setLabel(entry);
        _super.prototype.refreshContent.call(this, entry, highlight);
    };
    CustomChartMarkerView.prototype.getOffset = function () {
        var self = this;
        var padding = new com.github.mikephil.charting.utils.MPPointF(-(self.getWidth() / 2 - this.xOffset), -(self.getHeight() - this.xOffset));
        return padding;
    };
    CustomChartMarkerView.prototype.setLabel = function (entry) {
        var self = this;
        this.textView = self.findViewById(this.packageName.R.id.tvContent);
        var layout = self.findViewById(this.packageName.R.id.marker_layout);
        if (this.textView && layout) {
            var text = void 0;
            if (this.displayData) {
                text = this.displayData.formatter;
                var indexX = this.displayData.formatter.indexOf("{{x}}");
                var indexY = this.displayData.formatter.indexOf("{{y}}");
                var x = void 0;
                var y = void 0;
                if (this.displayData.fixedXValue) {
                    switch (this.displayData.fixedXValue.type) {
                        case "Int":
                            x = entry.getX().toFixed();
                            x = formatNumber(parseInt(x), {
                                fractionDigits: 0
                            });
                            break;
                        case "Float":
                            x = entry.getX().toFixed(this.displayData.fixedXValue.numberOfDigits);
                            x = formatNumber(parseInt(x), {
                                fractionDigits: this.displayData.fixedXValue.numberOfDigits
                            });
                            break;
                        default:
                            break;
                    }
                }
                else {
                    x = entry.getX().toFixed();
                    x = formatNumber(parseInt(x), {
                        fractionDigits: 0
                    });
                }
                if (this.displayData.fixedYValue) {
                    switch (this.displayData.fixedYValue.type) {
                        case "Int":
                            y = entry.getY().toFixed();
                            y = formatNumber(parseInt(y), {
                                fractionDigits: 0
                            });
                            break;
                        case "Float":
                            y = entry.getY().toFixed(this.displayData.fixedYValue.numberOfDigits);
                            y = formatNumber(parseFloat(y), {
                                fractionDigits: this.displayData.fixedYValue.numberOfDigits
                            });
                            break;
                        default:
                            break;
                    }
                }
                else {
                    y = entry.getY().toFixed();
                    y = formatNumber(parseInt(y), {
                        fractionDigits: 0
                    });
                }
                if (this.displayData.showXValue && indexX != -1) {
                    text = text.replace("{{x}}", x);
                }
                if (this.displayData.showYValue && indexY != -1) {
                    text = text.replace("{{y}}", y);
                    console.log("text if", text);
                }
            }
            else {
                text = "Y Value: " + entry.getY().toFixed();
            }
            this.textView.setText(text);
            this.textView.setTextColor(this.textColor);
            this.textView.setTextAlignment(this.textAlignment);
            var drawable = new android.graphics.drawable.GradientDrawable();
            drawable.setCornerRadius(this.borderRadius);
            drawable.setColor(this.backgroundViewColor);
            layout.setBackground(drawable);
            layout.setPadding(this.paddingLeft, this.paddingTop, this.paddingRight, this.paddingBottom);
        }
        else {
            throw new Error("textView or layout undefined.. Check layoutResource input must be wrong");
        }
    };
    CustomChartMarkerView.prototype.setConfig = function (config) {
        console.log("setConfig");
        if (config.backgroundColor) {
            this.backgroundViewColor = config.backgroundColor.android;
        }
        if (config.textColor) {
            this.textColor = config.textColor.android;
        }
        if (config.fontSize) {
            this.fontSize = config.fontSize;
        }
        if (config.borderRadius) {
            this.borderRadius = config.borderRadius;
        }
        if (config.padding) {
            var x = config.padding.x ? config.padding.x : 0;
            var y = config.padding.y ? config.padding.y : 0;
            this.paddingTop = this.paddingBottom = y;
            this.paddingLeft = this.paddingRight = x;
        }
        if (config.minimumSize) {
            this.minWidth = config.minimumSize.width;
            this.minHeight = config.minimumSize.height;
        }
        if (config.displayData) {
            this.displayData = config.displayData;
        }
        if (config.xOffset) {
            this.xOffset = config.xOffset;
        }
        if (config.yOffset) {
            this.yOffset = config.yOffset;
        }
    };
    CustomChartMarkerView.prototype.setDefault = function () {
        this.backgroundViewColor = new color_1.Color("#cccccc").android;
        this.textColor = new color_1.Color("#000000").android;
        this.minWidth = 40;
        this.minHeight = 20;
        this.paddingTop = 5;
        this.paddingRight = 5;
        this.paddingBottom = 5;
        this.paddingLeft = 5;
        this.fontSize = 12;
        this.borderRadius = 5;
        this.textAlignment = 4;
        this.displayData = {
            showXValue: false,
            showYValue: true,
            fixedXValue: {
                type: "Int",
                numberOfDigits: 0
            },
            fixedYValue: {
                type: "Float",
                numberOfDigits: 2
            },
            formatter: "Y value: {{y}}"
        };
        this.xOffset = 0;
        this.yOffset = 0;
    };
    return CustomChartMarkerView;
}(com.github.mikephil.charting.components.MarkerView));
exports.CustomChartMarkerView = CustomChartMarkerView;
//# sourceMappingURL=nativescript-bar-chart.android.js.map