"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var nativescript_mpchart_common_1 = require("../nativescript-mpchart.common");
var color_1 = require("tns-core-modules/color");
var formatNumber = require("simple-format-number");
var MPBarChart = (function (_super) {
    __extends(MPBarChart, _super);
    function MPBarChart() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MPBarChart.prototype.createNativeView = function () {
        var barChartView = BarChartView.new();
        var description = ChartDescription.new();
        description.text = "";
        barChartView.chartDescription = description;
        barChartView.xAxis.labelPosition = 1;
        barChartView.xAxis.drawGridLinesEnabled = false;
        barChartView.leftAxis.drawGridLinesEnabled = false;
        barChartView.rightAxis.drawGridLinesEnabled = false;
        barChartView.leftAxis.enabled = true;
        barChartView.rightAxis.enabled = true;
        barChartView.xAxis.granularity = 1;
        barChartView.xAxis.axisMinimum = 0;
        barChartView.leftAxis.axisMinimum = 0;
        barChartView.rightAxis.axisMinimum = 0;
        barChartView.doubleTapToZoomEnabled = false;
        barChartView.fitBars = true;
        barChartView.setScaleEnabled(false);
        return barChartView;
    };
    MPBarChart.prototype.onLoaded = function () {
        this.nativeView.frame = CGRectMake(0, 0, this.nativeView.superview.frame.size.width, this.nativeView.superview.frame.size.height);
        _super.prototype.onLoaded.call(this);
    };
    MPBarChart.prototype.resetZoomLineChart = function () {
        this.nativeView.resetZoom();
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.itemsProperty.setNative] = function (items) {
        var barChartData = BarChartData.new();
        for (var i = 0; i < items.length; i++) {
            if (items[i].dataSet && items[i].dataSet.length) {
                var labelLegend = items[i].legendLabel ? items[i].legendLabel : "";
                var entries = NSMutableArray.new();
                for (var j = 0; j < items[i].dataSet.length; j++) {
                    var entrie = BarChartDataEntry.new().initWithXY(items[i].dataSet[j].x, items[i].dataSet[j].y);
                    entries.addObject(entrie);
                }
                var dataset = BarChartDataSet.alloc().initWithValuesLabel(entries, labelLegend);
                dataset.setColor(items[i].barColor.ios);
                if (items[i].highlighColor) {
                    dataset.highlightColor = items[i].highlighColor.ios;
                }
                dataset.highlightEnabled = true;
                if (this.showValueLabels != undefined) {
                    dataset.drawValuesEnabled = this.showValueLabels;
                }
                else {
                    dataset.drawValuesEnabled = true;
                }
                barChartData.addDataSet(dataset);
            }
            else {
                throw new Error("items number " + i + "do not have any item");
            }
        }
        this.nativeView.barChartData = barChartData;
        this.nativeView.setData();
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.labelsProperty.setNative] = function (labels) {
        console.log("labelsProperty labels", labels.length);
        if (labels) {
            var formatter = ChartDefaultAxisValueFormatter.alloc().initWithBlock(function (value, axis) {
                for (var i = 0; i < labels.length; i++) {
                    if (labels[i].xAxisValue == value) {
                        return labels[i].label + '';
                    }
                }
                return "";
            });
            var xAxis = this.nativeView.xAxis;
            if (xAxis) {
                xAxis.valueFormatter = formatter;
            }
            else {
                throw new Error("xAxis in labels Property setup undefined");
            }
        }
        else {
            throw new Error("labels value undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.showLegendProperty.setNative] = function (value) {
        var legend = this.nativeView.legend;
        console.log("showLegend ", value);
        if (legend) {
            legend.enabled = value;
        }
        else {
            throw new Error("Property 'legend' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.showGridLinesProperty.setNative] = function (value) {
        var xAxis;
        var leftAxis;
        var rightAxis;
        xAxis = this.nativeView.xAxis;
        leftAxis = this.nativeView.leftAxis;
        rightAxis = this.nativeView.rightAxis;
        if (xAxis && leftAxis && rightAxis) {
            xAxis.drawGridLinesEnabled = value;
            leftAxis.drawGridLinesEnabled = value;
            rightAxis.drawGridLinesEnabled = value;
        }
        else {
            throw new Error("Property 'xAxis' or 'leftAxis' or 'rightAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.scaleEnableProperty.setNative] = function (value) {
        this.nativeView.setScaleEnabled(value);
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.descriptionTextProperty.setNative] = function (value) {
        this.nativeView.chartDescription.text = value;
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.descriptionXOffsetProperty.setNative] = function (value) {
        this.nativeView.chartDescription.xOffset = value;
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.descriptionYOffsetProperty.setNative] = function (value) {
        this.nativeView.chartDescription.yOffset = value;
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.descriptionTextColorProperty.setNative] = function (value) {
        this.nativeView.chartDescription.textColor = value.ios;
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.descriptionTextColorCssProperty.setNative] = function (value) {
        this.nativeView.chartDescription.textColor = value.ios;
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.xAxisGranularityProperty.setNative] = function (value) {
        var xAxis;
        xAxis = this.nativeView.xAxis;
        if (xAxis) {
            xAxis.granularity = value;
        }
        else {
            throw new Error("Property 'xAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.leftAxisGranularityProperty.setNative] = function (value) {
        var leftAxis;
        leftAxis = this.nativeView.leftAxis;
        if (leftAxis) {
            leftAxis.granularity = value;
        }
        else {
            throw new Error("Property 'leftAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.rightAxisGranularityProperty.setNative] = function (value) {
        var rightAxis;
        rightAxis = this.nativeView.rightAxis;
        if (rightAxis) {
            rightAxis.granularity = value;
        }
        else {
            throw new Error("Property  'rightAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.xAxisLabelPositionProperty.getDefault] = function () {
        return "Bottom";
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.xAxisLabelPositionProperty.setNative] = function (value) {
        var xAxis = this.nativeView.xAxis;
        if (xAxis) {
            switch (value) {
                case "Top":
                    this.nativeView.xAxis.labelPosition = 0;
                    break;
                case "Bottom":
                    this.nativeView.xAxis.labelPosition = 1;
                    break;
                case "BothSided":
                    this.nativeView.xAxis.labelPosition = 2;
                    break;
                case "TopInside":
                    this.nativeView.xAxis.labelPosition = 3;
                    break;
                case "BottomInside":
                    this.nativeView.xAxis.labelPosition = 4;
                    break;
                default:
                    console.log("Value of xAxisLabelPosition property do not exist, default value will set Bottom");
                    break;
            }
            this.nativeView.frame = CGRectMake(0, 0, this.nativeView.superview.frame.size.width, this.nativeView.superview.frame.size.height);
        }
        else {
            throw new Error("Property 'xAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.xAxisLineColorProperty.setNative] = function (value) {
        var xAxis;
        xAxis = this.nativeView.xAxis;
        if (xAxis) {
            xAxis.axisLineColor = value.ios;
        }
        else {
            throw new Error("Property  'xAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.xAxisLineColorCssProperty.setNative] = function (value) {
        var xAxis;
        xAxis = this.nativeView.xAxis;
        if (xAxis) {
            xAxis.axisLineColor = value.ios;
        }
        else {
            throw new Error("Property  'xAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.leftAxisLineColorProperty.setNative] = function (value) {
        var leftAxis;
        leftAxis = this.nativeView.leftAxis;
        if (leftAxis) {
            leftAxis.axisLineColor = value.ios;
        }
        else {
            throw new Error("Property  'leftAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.leftAxisLineColorCssProperty.setNative] = function (value) {
        var leftAxis;
        leftAxis = this.nativeView.leftAxis;
        if (leftAxis) {
            leftAxis.axisLineColor = value.ios;
        }
        else {
            throw new Error("Property  'leftAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.rightAxisLineColorProperty.setNative] = function (value) {
        var rightAxis;
        rightAxis = this.nativeView.rightAxis;
        if (rightAxis) {
            rightAxis.axisLineColor = value.ios;
        }
        else {
            throw new Error("Property  'rightAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.rightAxisLineColorCssProperty.setNative] = function (value) {
        var rightAxis;
        rightAxis = this.nativeView.rightAxis;
        if (rightAxis) {
            rightAxis.axisLineColor = value.ios;
        }
        else {
            throw new Error("Property  'rightAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.xAxisTextColorProperty.setNative] = function (value) {
        var xAxis;
        xAxis = this.nativeView.xAxis;
        if (xAxis && value) {
            xAxis.labelTextColor = value.ios;
        }
        else {
            throw new Error("Property  'xAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.xAxisTextColorCssProperty.setNative] = function (value) {
        var xAxis;
        xAxis = this.nativeView.xAxis;
        if (xAxis && value) {
            xAxis.labelTextColor = value.ios;
        }
        else {
            throw new Error("Property  'xAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.leftAxisTextColorProperty.setNative] = function (value) {
        var leftAxis;
        leftAxis = this.nativeView.leftAxis;
        if (leftAxis && value) {
            leftAxis.labelTextColor = value.ios;
        }
        else {
            throw new Error("Property  'leftAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.leftAxisTextColorCssProperty.setNative] = function (value) {
        var leftAxis;
        leftAxis = this.nativeView.leftAxis;
        if (leftAxis && value) {
            leftAxis.labelTextColor = value.ios;
        }
        else {
            throw new Error("Property  'leftAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.rightAxisTextColorProperty.setNative] = function (value) {
        var rightAxis;
        rightAxis = this.nativeView.rightAxis;
        if (rightAxis && value) {
            rightAxis.labelTextColor = value.ios;
        }
        else {
            throw new Error("Property  'rightAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.rightAxisTextColorCssProperty.setNative] = function (value) {
        var rightAxis;
        rightAxis = this.nativeView.rightAxis;
        if (rightAxis && value) {
            rightAxis.labelTextColor = value.ios;
        }
        else {
            throw new Error("Property  'rightAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.xAxisMinValueProperty.setNative] = function (value) {
        var xAxis;
        xAxis = this.nativeView.xAxis;
        if (xAxis) {
            xAxis.axisMinimum = value;
        }
        else {
            throw new Error("Property  'xAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.xAxisMaxValueProperty.setNative] = function (value) {
        var xAxis;
        xAxis = this.nativeView.xAxis;
        if (xAxis) {
            xAxis.axisMaximum = value;
        }
        else {
            throw new Error("Property  'xAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.leftAxisMinValueProperty.setNative] = function (value) {
        var leftAxis;
        leftAxis = this.nativeView.leftAxis;
        if (leftAxis) {
            leftAxis.axisMinimum = value;
        }
        else {
            throw new Error("Property  'xAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.leftAxisMaxValueProperty.setNative] = function (value) {
        var leftAxis;
        leftAxis = this.nativeView.leftAxis;
        if (leftAxis) {
            leftAxis.axisMaximum = value;
        }
        else {
            throw new Error("Property  'xAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.rightAxisMinValueProperty.setNative] = function (value) {
        var rightAxis;
        rightAxis = this.nativeView.rightAxis;
        if (rightAxis) {
            rightAxis.axisMinimum = value;
        }
        else {
            throw new Error("Property  'xAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.rightAxisMaxValueProperty.setNative] = function (value) {
        var rightAxis;
        rightAxis = this.nativeView.rightAxis;
        if (rightAxis) {
            rightAxis.axisMaximum = value;
        }
        else {
            throw new Error("Property  'xAxis' of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.leftAxisFormatterProperty.setNative] = function (formatterValue) {
        if (formatterValue) {
            var leftAxis = this.nativeView.leftAxis;
            switch (formatterValue.type) {
                case "Int":
                    var formatter = ChartDefaultAxisValueFormatter.alloc().initWithBlock(function (value, axis) {
                        if (value == 0 || value) {
                            return value.toFixed();
                        }
                        else {
                            return "";
                        }
                    });
                    leftAxis.valueFormatter = formatter;
                    break;
                case "Float":
                    var formatter = ChartDefaultAxisValueFormatter.alloc().initWithBlock(function (value, axis) {
                        if (value == 0 || value) {
                            return value.toFixed(formatterValue.numberOfDigits);
                        }
                        else {
                            return "";
                        }
                    });
                    leftAxis.valueFormatter = formatter;
                    break;
                default:
                    break;
            }
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.rightAxisFormatterProperty.setNative] = function (formatterValue) {
        if (formatterValue) {
            var rightAxis = this.nativeView.rightAxis;
            switch (formatterValue.type) {
                case "Int":
                    var formatter = ChartDefaultAxisValueFormatter.alloc().initWithBlock(function (value, axis) {
                        if (value == 0 || value) {
                            return value.toFixed();
                        }
                        else {
                            return "";
                        }
                    });
                    rightAxis.valueFormatter = formatter;
                    break;
                case "Float":
                    var formatter = ChartDefaultAxisValueFormatter.alloc().initWithBlock(function (value, axis) {
                        if (value == 0 || value) {
                            return value.toFixed(formatterValue.numberOfDigits);
                        }
                        else {
                            return "";
                        }
                    });
                    rightAxis.valueFormatter = formatter;
                    break;
                default:
                    break;
            }
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.fontProperty.setNative] = function (fontName) {
        var font;
        var familyNames = UIFont.familyNames;
        var xAxis = this.nativeView.xAxis;
        var leftAxis = this.nativeView.leftAxis;
        var rightAxis = this.nativeView.rightAxis;
        for (var i = 0; i < familyNames.count; ++i) {
            if (familyNames[i] == fontName) {
                font = fontName;
                break;
            }
            var famName = familyNames[i];
            var fontNamesForFamily = UIFont.fontNamesForFamilyName(famName);
            for (var k = 0; k < fontNamesForFamily.count; ++k) {
                if (fontName == fontNamesForFamily[k]) {
                    font = fontName;
                    break;
                }
            }
        }
        if (font) {
            if (xAxis) {
                console.log(" xAxis.labelFont ", xAxis.labelFont.fontName);
                xAxis.labelFont = UIFont.fontWithNameSize(font, xAxis.labelFont.pointSize);
            }
            if (leftAxis) {
                leftAxis.labelFont = UIFont.fontWithNameSize(font, leftAxis.labelFont.pointSize);
            }
            if (rightAxis) {
                rightAxis.labelFont = UIFont.fontWithNameSize(font, rightAxis.labelFont.pointSize);
            }
            if (this.nativeView.data) {
                var dataSets = this.nativeView.data.dataSets;
                if (dataSets) {
                    for (var i_1 = 0; i_1 < dataSets.count; i_1++) {
                        dataSets[i_1].valueFont = UIFont.fontWithNameSize(font, dataSets[i_1].valueFont.pointSize);
                    }
                }
            }
            if (this.nativeView.legend) {
                this.nativeView.legend.font = UIFont.fontWithNameSize(font, this.nativeView.legend.font.pointSize);
            }
            if (this.nativeView.description) {
                this.nativeView.chartDescription.font = UIFont.fontWithNameSize(font, this.nativeView.chartDescription.font.pointSize);
            }
        }
        else {
            throw new Error("xAxisFontProperty Font " + fontName + " Do not exist");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.showValueLabelsProperty.getDefault] = function () {
        return true;
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.showValueLabelsProperty.setNative] = function (value) {
        this.showValueLabels = value;
        if (this.nativeView.data) {
            var dataSets = this.nativeView.data.dataSets;
            if (dataSets) {
                for (var i = 0; i < dataSets.count; i++) {
                    dataSets[i].drawValuesEnabled = value;
                }
            }
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.showLeftAxisProperty.setNative] = function (value) {
        var leftAxis;
        leftAxis = this.nativeView.leftAxis;
        if (leftAxis) {
            leftAxis.enabled = value;
        }
        else {
            throw new Error("Property  'xAxis' in showLeftAxisProperty of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.showRightAxisProperty.setNative] = function (value) {
        var rightAxis;
        rightAxis = this.nativeView.rightAxis;
        if (rightAxis) {
            rightAxis.enabled = value;
        }
        else {
            throw new Error("Property  'xAxis' in showRightAxisProperty of Chart undefined");
        }
    };
    MPBarChart.prototype[nativescript_mpchart_common_1.markerProperty.setNative] = function (markerConfig) {
        console.log("markerProperty");
        var marker = CustomChartMarkerView.alloc().initWithFrame(CGRectMake(0, 0, 100, 100));
        marker.setConfig(markerConfig);
        this.nativeView.marker = marker;
    };
    return MPBarChart;
}(nativescript_mpchart_common_1.MPChartBase));
exports.MPBarChart = MPBarChart;
var CustomChartMarkerView = (function (_super) {
    __extends(CustomChartMarkerView, _super);
    function CustomChartMarkerView() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CustomChartMarkerView.prototype.initWithFrame = function (frame) {
        this.setDefault();
        return _super.prototype.initWithFrame.call(this, frame);
    };
    CustomChartMarkerView.prototype.refreshContentWithEntryHighlight = function (entry, highlight) {
        this.setLabel(entry);
    };
    CustomChartMarkerView.prototype.removeAllSubview = function () {
        for (var i = 0; i < this.subviews.count; i++) {
            this.subviews[i].removeFromSuperview();
        }
    };
    CustomChartMarkerView.prototype.setLabel = function (entry) {
        var text;
        if (this.displayData) {
            text = this.displayData.formatter;
            var indexX = this.displayData.formatter.indexOf("{{x}}");
            var indexY = this.displayData.formatter.indexOf("{{y}}");
            var x = void 0;
            var y = void 0;
            if (this.displayData.fixedXValue) {
                switch (this.displayData.fixedXValue.type) {
                    case "Int":
                        x = entry.x.toFixed();
                        x = formatNumber(parseInt(x), {
                            fractionDigits: 0
                        });
                        break;
                    case "Float":
                        x = entry.x.toFixed(this.displayData.fixedXValue.numberOfDigits);
                        x = formatNumber(parseFloat(x), {
                            fractionDigits: this.displayData.fixedXValue.numberOfDigits
                        });
                        break;
                    default:
                        break;
                }
            }
            else {
                x = entry.x.toFixed();
                x = formatNumber(parseInt(x), {
                    fractionDigits: 0
                });
            }
            if (this.displayData.fixedYValue) {
                switch (this.displayData.fixedYValue.type) {
                    case "Int":
                        y = entry.y.toFixed();
                        y = formatNumber(parseInt(y), {
                            fractionDigits: 0
                        });
                        break;
                    case "Float":
                        y = entry.y.toFixed(this.displayData.fixedYValue.numberOfDigits);
                        y = formatNumber(parseFloat(y), {
                            fractionDigits: this.displayData.fixedXValue.numberOfDigits
                        });
                        break;
                    default:
                        break;
                }
            }
            else {
                y = entry.y.toFixed();
                y = formatNumber(parseInt(y), {
                    fractionDigits: 0
                });
            }
            if (this.displayData.showXValue && indexX != -1) {
                text = text.replace("{{x}}", x);
            }
            if (this.displayData.showYValue && indexY != -1) {
                text = text.replace("{{y}}", y);
            }
            this.nsStringLabel = NSString.alloc().initWithString(text);
        }
        else {
            text = "Y Value: " + entry.y.toFixed();
            this.nsStringLabel = NSString.alloc().initWithString(text);
        }
        this.drawAttributes = NSMutableDictionary.alloc().init();
        if (this.font) {
            this.drawAttributes.setObjectForKey(this.font, NSFontAttributeName);
        }
        this.labelSize = this.nsStringLabel.sizeWithAttributes(this.drawAttributes);
        var size = CGSizeMake(0, 0);
        size.width = this.labelSize.width + this.insets.left + this.insets.right;
        size.height = this.labelSize.height + this.insets.top + this.insets.bottom;
        size.width = Math.max(this.minimumSize.width, size.width);
        size.height = Math.max(this.minimumSize.height, size.height);
        this.label = UILabel.alloc().initWithFrame(CGRectMake(0, 0, this.labelSize.width, this.labelSize.height));
        var view = UIView.alloc().initWithFrame(CGRectMake(0 + this.xOffset - this.labelSize.width / 2, 0 + this.yOffset - this.labelSize.height, size.width, size.height));
        this.label.lineBreakMode = 0;
        this.label.numberOfLines = 0;
        this.label.backgroundColor = UIColor.clearColor;
        this.label.text = text;
        if (this.contentCenter) {
            this.label.center = CGPointMake(view.frame.size.width / 2, view.frame.size.height / 2);
        }
        this.label.textColor = this.textColor;
        this.label.font = this.font;
        this.label.textAlignment = 1;
        view.backgroundColor = this.backgroundViewColor;
        view.layer.cornerRadius = this.borderRadius;
        view.addSubview(this.label);
        this.removeAllSubview();
        this.addSubview(view);
    };
    CustomChartMarkerView.prototype.setConfig = function (config) {
        console.log("setConfig");
        if (config.backgroundColor) {
            this.backgroundViewColor = config.backgroundColor.ios;
        }
        if (config.textColor) {
            this.textColor = config.textColor.ios;
        }
        if (config.fontSize) {
            this.fontSize = config.fontSize;
        }
        if (config.borderRadius) {
            this.borderRadius = config.borderRadius;
        }
        if (config.padding) {
            var x = config.padding.x ? config.padding.x : 0;
            var y = config.padding.y ? config.padding.y : 0;
            this.insets = UIEdgeInsetsMake(y, x, y, x);
        }
        if (config.minimumSize) {
            this.minimumSize = CGSizeMake(config.minimumSize.width, config.minimumSize.height);
        }
        if (config.font) {
            var font;
            var familyNames = UIFont.familyNames;
            for (var i = 0; i < familyNames.count; ++i) {
                if (familyNames[i] == config.font) {
                    font = config.font;
                    break;
                }
                var famName = familyNames[i];
                var fontNamesForFamily = UIFont.fontNamesForFamilyName(famName);
                for (var k = 0; k < fontNamesForFamily.count; ++k) {
                    if (config.font == fontNamesForFamily[k]) {
                        font = config.font;
                        break;
                    }
                }
            }
            var fontSize = config.fontSize ? config.fontSize : UIFont.systemFontSize;
            if (font) {
                this.font = UIFont.fontWithNameSize(font, fontSize);
            }
        }
        if (config.contentCenter != undefined || config.contentCenter != null) {
            this.contentCenter = config.contentCenter;
        }
        if (config.displayData) {
            this.displayData = config.displayData;
        }
        if (config.xOffset) {
            this.xOffset = config.xOffset;
        }
        if (config.yOffset) {
            this.yOffset = config.yOffset;
        }
    };
    CustomChartMarkerView.prototype.setDefault = function () {
        this.backgroundViewColor = new color_1.Color("#cccccc").ios;
        this.textColor = new color_1.Color("#000000").ios;
        this.minimumSize = CGSizeMake(20, 10);
        this.insets = UIEdgeInsetsMake(5, 5, 5, 5);
        this.fontSize = UIFont.systemFontSize;
        this.borderRadius = 5;
        this.font = UIFont.systemFontOfSize(UIFont.systemFontSize);
        this.contentCenter = true;
        this.displayData = {
            showXValue: false,
            showYValue: true,
            fixedXValue: {
                type: "Int",
                numberOfDigits: 0
            },
            fixedYValue: {
                type: "Float",
                numberOfDigits: 2
            },
            formatter: "Y value: {{y}}"
        };
        this.xOffset = 0;
        this.yOffset = 0;
    };
    return CustomChartMarkerView;
}(ChartMarkerView));
exports.CustomChartMarkerView = CustomChartMarkerView;
//# sourceMappingURL=nativescript-bar-chart.ios.js.map