"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var nativescript_mpchart_common_1 = require("../nativescript-mpchart.common");
var LineChart = com.github.mikephil.charting.charts.LineChart;
var LineDataSet = com.github.mikephil.charting.data.LineDataSet;
var LineData = com.github.mikephil.charting.data.LineData;
var Entry = com.github.mikephil.charting.data.Entry;
var ArrayList = java.util.ArrayList;
var XAxis = com.github.mikephil.charting.components.XAxis;
var IndexAxisValueFormatter = com.github.mikephil.charting.formatter.IndexAxisValueFormatter;
var DefaultValueFormatter = com.github.mikephil.charting.formatter.DefaultValueFormatter;
var IAxisValueFormatter = com.github.mikephil.charting.formatter.IAxisValueFormatter;
var Description = com.github.mikephil.charting.components.Description;
var IValueFormatter = com.github.mikephil.charting.formatter.IValueFormatter;
var MPLineChart = (function (_super) {
    __extends(MPLineChart, _super);
    function MPLineChart() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MPLineChart.prototype.resetZoomLineChart = function () {
        this.nativeView.resetZoom();
    };
    MPLineChart.prototype.createNativeView = function () {
        var lineChartView = new LineChart(this._context);
        var xAxis = lineChartView.getXAxis();
        var yAxisLeft = lineChartView.getAxisLeft();
        var yAxisRight = lineChartView.getAxisRight();
        xAxis.setDrawGridLines(false);
        yAxisLeft.setDrawGridLines(false);
        yAxisRight.setDrawGridLines(false);
        xAxis.setGranularity(1);
        xAxis.setDrawGridLines(false);
        yAxisLeft.setDrawGridLines(false);
        yAxisRight.setDrawGridLines(false);
        yAxisLeft.setEnabled(true);
        yAxisRight.setEnabled(true);
        yAxisLeft.setDrawLabels(true);
        yAxisRight.setDrawLabels(true);
        var description = new Description();
        description.setText("");
        lineChartView.setDescription(description);
        lineChartView.setDoubleTapToZoomEnabled(false);
        lineChartView.setScaleEnabled(false);
        return lineChartView;
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.itemsProperty.setNative] = function (items) {
        var lineDatasets = new ArrayList();
        for (var i = 0; i < items.length; i++) {
            if (items[i].dataSet && items[i].dataSet.length) {
                var labelLegend = items[i].legendLabel ? items[i].legendLabel : "";
                var entries = [];
                for (var j = 0; j < items[i].dataSet.length; j++) {
                    var entrie = new Entry(items[i].dataSet[j].x, items[i].dataSet[j].y);
                    entries.push(entrie);
                }
                if (entries.length) {
                    var dataset = new LineDataSet(new ArrayList(java.util.Arrays.asList(entries)), labelLegend);
                    dataset.setColor(items[i].lineColor.android);
                    var drawCircle = items[i].circleHoleEnabled ? !!items[i].circleHoleEnabled : false;
                    dataset.setDrawCircleHole(drawCircle);
                    if (items[i].circleColor) {
                        dataset.setCircleColor(items[i].circleColor.android);
                    }
                    dataset.setCircleHoleRadius(3);
                    var circleEnable = items[i].circleEnable ? !!items[i].circleEnable : false;
                    dataset.setHighlightEnabled(false);
                    if (items[i].highlighColor) {
                        dataset.setHighLightColor(items[i].highlighColor.android);
                    }
                    if (this.showValueLabels != undefined) {
                        dataset.setDrawValues(this.showValueLabels);
                    }
                    else {
                        dataset.setDrawValues(true);
                    }
                    lineDatasets.add(dataset);
                }
            }
            else {
                throw new Error("items number " + i + "do not have any item");
            }
        }
        var lineChartData = new LineData(lineDatasets);
        this.nativeView.setData(lineChartData);
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.labelsProperty.setNative] = function (labels) {
        var self = this;
        if (labels) {
            if (this.nativeView.getXAxis()) {
                this.nativeView.getXAxis().setValueFormatter(new IAxisValueFormatter({
                    getFormattedValue: function (value, entry) {
                        for (var i = 0; i < labels.length; i++) {
                            if (labels[i].xAxisValue == value) {
                                return labels[i].label + '';
                            }
                        }
                        return "";
                    }
                }));
            }
            else {
                throw new Error("xAxis in labels Property setup undefined");
            }
        }
        else {
            throw new Error("labels value undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.showLegendProperty.setNative] = function (value) {
        var legend = this.nativeView.getLegend();
        console.log("showLegend ", value);
        if (legend) {
            legend.setEnabled(value);
        }
        else {
            throw new Error("Property 'legend' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.showGridLinesProperty.setNative] = function (value) {
        var xAxis;
        var leftAxis;
        var rightAxis;
        xAxis = this.nativeView.getXAxis();
        leftAxis = this.nativeView.getAxisLeft();
        rightAxis = this.nativeView.getAxisRight();
        if (xAxis && leftAxis && rightAxis) {
            xAxis.setDrawGridLines(value);
            leftAxis.setDrawGridLines(value);
            rightAxis.setDrawGridLines(value);
        }
        else {
            throw new Error("Property 'xAxis' or 'leftAxis' or 'rightAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.scaleEnableProperty.setNative] = function (value) {
        this.nativeView.setScaleEnabled(value);
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.descriptionTextProperty.setNative] = function (value) {
        var chartDescription = this.nativeView.getDescription().setText(value);
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.descriptionXOffsetProperty.setNative] = function (value) {
        this.nativeView.getDescription().setXOffset(value);
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.descriptionYOffsetProperty.setNative] = function (value) {
        this.nativeView.getDescription().setYOffset(value);
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.descriptionTextColorProperty.setNative] = function (value) {
        this.nativeView.getDescription().setTextColor(value.android);
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.descriptionTextColorCssProperty.setNative] = function (value) {
        this.nativeView.getDescription().setTextColor(value.android);
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.highlightPerTapEnabledProperty.setNative] = function (value) {
        this.nativeView.setHighlightPerTapEnabled(value);
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.highlightPerDragEnabledProperty.setNative] = function (value) {
        this.nativeView.setHighlightPerDragEnabled(value);
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.xAxisGranularityProperty.setNative] = function (value) {
        if (this.nativeView.getXAxis()) {
            this.nativeView.getXAxis().setGranularity(value);
        }
        else {
            throw new Error("Property 'xAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.leftAxisGranularityProperty.setNative] = function (value) {
        if (this.nativeView.getAxisLeft()) {
            this.nativeView.getAxisLeft().setGranularity(value);
        }
        else {
            throw new Error("Property 'leftAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.rightAxisGranularityProperty.setNative] = function (value) {
        if (this.nativeView.getAxisRight()) {
            this.nativeView.getAxisRight().setGranularity(value);
        }
        else {
            throw new Error("Property 'rightAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.xAxisLabelPositionProperty.getDefault] = function () {
        return "Bottom";
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.xAxisLabelPositionProperty.setNative] = function (value) {
        var xAxis = this.nativeView.getXAxis();
        if (xAxis) {
            switch (value) {
                case "Top":
                    this.nativeView.getXAxis().setPosition(XAxis.XAxisPosition.TOP);
                    break;
                case "Bottom":
                    this.nativeView.getXAxis().setPosition(XAxis.XAxisPosition.BOTTOM);
                    break;
                case "BothSided":
                    this.nativeView.getXAxis().setPosition(XAxis.XAxisPosition.BOTH_SIDED);
                    break;
                case "TopInside":
                    this.nativeView.getXAxis().setPosition(XAxis.XAxisPosition.TOP_INSIDE);
                    break;
                case "BottomInside":
                    this.nativeView.getXAxis().setPosition(XAxis.XAxisPosition.BOTTOM_INSIDE);
                    break;
                default:
                    console.log("Value of xAxisLabelPosition property do not exist, default value will set Bottom");
                    break;
            }
        }
        else {
            throw new Error("Property 'xAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.xAxisLineColorProperty.setNative] = function (value) {
        var xAxis;
        xAxis = this.nativeView.getXAxis();
        if (xAxis && value) {
            xAxis.setAxisLineColor(value.android);
        }
        else {
            throw new Error("Property  'xAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.xAxisLineColorCssProperty.setNative] = function (value) {
        var xAxis;
        xAxis = this.nativeView.getXAxis();
        if (xAxis && value) {
            xAxis.setAxisLineColor(value.android);
        }
        else {
            throw new Error("Property  'xAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.leftAxisLineColorProperty.setNative] = function (value) {
        var leftAxis;
        leftAxis = this.nativeView.getAxisLeft();
        if (leftAxis && value) {
            leftAxis.setAxisLineColor(value.android);
        }
        else {
            throw new Error("Property  'leftAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.leftAxisLineColorCssProperty.setNative] = function (value) {
        var leftAxis;
        leftAxis = this.nativeView.getAxisLeft();
        if (leftAxis && value) {
            leftAxis.setAxisLineColor(value.android);
        }
        else {
            throw new Error("Property  'leftAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.rightAxisLineColorProperty.setNative] = function (value) {
        var rightAxis;
        rightAxis = this.nativeView.getAxisRight();
        if (rightAxis && value) {
            rightAxis.setAxisLineColor(value.android);
        }
        else {
            throw new Error("Property  'rightAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.rightAxisLineColorCssProperty.setNative] = function (value) {
        var rightAxis;
        rightAxis = this.nativeView.getAxisRight();
        if (rightAxis && value) {
            rightAxis.setAxisLineColor(value.android);
        }
        else {
            throw new Error("Property  'rightAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.xAxisTextColorProperty.setNative] = function (value) {
        var xAxis;
        xAxis = this.nativeView.getXAxis();
        if (xAxis && value) {
            xAxis.setTextColor(value.android);
        }
        else {
            throw new Error("Property  'xAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.xAxisTextColorCssProperty.setNative] = function (value) {
        var xAxis;
        xAxis = this.nativeView.getXAxis();
        if (xAxis && value) {
            xAxis.setTextColor(value.android);
        }
        else {
            throw new Error("Property  'xAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.leftAxisTextColorProperty.setNative] = function (value) {
        var leftAxis;
        leftAxis = this.nativeView.getAxisLeft();
        if (leftAxis && value) {
            leftAxis.setTextColor(value.android);
        }
        else {
            throw new Error("Property  'leftAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.leftAxisTextColorCssProperty.setNative] = function (value) {
        var leftAxis;
        leftAxis = this.nativeView.getAxisLeft();
        if (leftAxis && value) {
            leftAxis.setTextColor(value.android);
        }
        else {
            throw new Error("Property  'leftAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.rightAxisTextColorProperty.setNative] = function (value) {
        var rightAxis;
        rightAxis = this.nativeView.getAxisRight();
        if (rightAxis && value) {
            rightAxis.setTextColor(value.android);
        }
        else {
            throw new Error("Property  'rightAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.rightAxisTextColorCssProperty.setNative] = function (value) {
        var rightAxis;
        rightAxis = this.nativeView.getAxisRight();
        if (rightAxis && value) {
            rightAxis.setTextColor(value.android);
        }
        else {
            throw new Error("Property  'rightAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.xAxisMinValueProperty.setNative] = function (value) {
        var xAxis;
        xAxis = this.nativeView.getXAxis();
        if (xAxis) {
            console.log("xAxisMinValueProperty ", value);
            xAxis.setAxisMinimum(value);
        }
        else {
            throw new Error("Property  'xAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.xAxisMaxValueProperty.setNative] = function (value) {
        var xAxis;
        xAxis = this.nativeView.getXAxis();
        if (xAxis) {
            console.log("xAxisMinValueProperty ", value);
            xAxis.setAxisMaximum(value);
        }
        else {
            throw new Error("Property  'xAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.leftAxisMinValueProperty.setNative] = function (value) {
        var leftAxis;
        leftAxis = this.nativeView.getAxisLeft();
        if (leftAxis) {
            leftAxis.setAxisMinimum(value);
        }
        else {
            throw new Error("Property  'leftAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.leftAxisMaxValueProperty.setNative] = function (value) {
        var leftAxis;
        leftAxis = this.nativeView.getAxisLeft();
        if (leftAxis) {
            leftAxis.setAxisMaximum(value);
        }
        else {
            throw new Error("Property  'leftAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.leftAxisMaxValueProperty.setNative] = function (value) {
        var rightAxis;
        rightAxis = this.nativeView.getAxisRight();
        if (rightAxis) {
            rightAxis.setAxisMinimum(value);
        }
        else {
            throw new Error("Property  'rightAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.rightAxisMaxValueProperty.setNative] = function (value) {
        var rightAxis;
        rightAxis = this.nativeView.getAxisRight();
        if (rightAxis) {
            rightAxis.setAxisMaximum(value);
        }
        else {
            throw new Error("Property  'rightAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.leftAxisFormatterProperty.setNative] = function (formatterValue) {
        if (formatterValue) {
            var leftAxis = this.nativeView.getAxisLeft();
            var formatter = void 0;
            switch (formatterValue.type) {
                case "Int":
                    formatter = new IAxisValueFormatter({
                        getFormattedValue: function (value, entry) {
                            if (value == 0 || value) {
                                return value.toFixed();
                            }
                            else {
                                return "";
                            }
                        }
                    });
                    leftAxis.setValueFormatter(formatter);
                    break;
                case "Float":
                    formatter = new IAxisValueFormatter({
                        getFormattedValue: function (value, entry) {
                            if (value == 0 || value) {
                                return value.toFixed(formatterValue.numberOfDigits);
                            }
                            else {
                                return "";
                            }
                        }
                    });
                    leftAxis.setValueFormatter(formatter);
                    break;
                default:
                    break;
            }
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.rightAxisFormatterProperty.setNative] = function (formatterValue) {
        if (formatterValue) {
            var rightAxis = this.nativeView.getAxisRight();
            var formatter = void 0;
            switch (formatterValue.type) {
                case "Int":
                    formatter = new IAxisValueFormatter({
                        getFormattedValue: function (value, entry) {
                            if (value == 0 || value) {
                                return value.toFixed();
                            }
                            else {
                                return "";
                            }
                        }
                    });
                    rightAxis.setValueFormatter(formatter);
                    break;
                case "Float":
                    formatter = new IAxisValueFormatter({
                        getFormattedValue: function (value, entry) {
                            if (value == 0 || value) {
                                return value.toFixed(formatterValue.numberOfDigits);
                            }
                            else {
                                return "";
                            }
                        }
                    });
                    rightAxis.setValueFormatter(formatter);
                    break;
                default:
                    break;
            }
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.showValueLabelsProperty.getDefault] = function () {
        return true;
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.showValueLabelsProperty.setNative] = function (value) {
        this.showValueLabels = value;
        if (this.nativeView.getData()) {
            var dataSets = this.nativeView.getData().getDataSets();
            if (dataSets) {
                for (var i = 0; i < dataSets.size(); i++) {
                    this.nativeView.getData().getDataSets().get(i).setDrawValues(value);
                }
            }
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.showLeftAxisProperty.setNative] = function (value) {
        var leftAxis;
        leftAxis = this.nativeView.getAxisLeft();
        if (leftAxis) {
            leftAxis.setEnabled(value);
        }
        else {
            throw new Error("Property  'xAxis' in showLeftAxisProperty of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.showRightAxisProperty.setNative] = function (value) {
        var rightAxis;
        rightAxis = this.nativeView.getAxisRight();
        if (rightAxis) {
            rightAxis.setEnabled(value);
        }
        else {
            throw new Error("Property  'xAxis' in showRightAxisProperty of Chart undefined");
        }
    };
    return MPLineChart;
}(nativescript_mpchart_common_1.MPChartBase));
exports.MPLineChart = MPLineChart;
//# sourceMappingURL=nativescript-line-chart.android.js.map