"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var nativescript_mpchart_common_1 = require("../nativescript-mpchart.common");
var MPLineChart = (function (_super) {
    __extends(MPLineChart, _super);
    function MPLineChart() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MPLineChart.prototype.createNativeView = function () {
        var dataset;
        var lineChartView = LineChartView.new();
        var description = ChartDescription.new();
        description.text = "";
        lineChartView.chartDescription = description;
        lineChartView.xAxis.labelPosition = 1;
        lineChartView.xAxis.drawGridLinesEnabled = false;
        lineChartView.leftAxis.drawGridLinesEnabled = false;
        lineChartView.rightAxis.drawGridLinesEnabled = false;
        lineChartView.highlightPerDragEnabled = false;
        lineChartView.highlightPerTapEnabled = false;
        lineChartView.leftAxis.enabled = true;
        lineChartView.rightAxis.enabled = true;
        lineChartView.xAxis.granularity = 1;
        lineChartView.xAxis.axisMinimum = 0;
        lineChartView.leftAxis.axisMinimum = 0;
        lineChartView.rightAxis.axisMinimum = 0;
        lineChartView.doubleTapToZoomEnabled = false;
        lineChartView.setScaleEnabled(false);
        return lineChartView;
    };
    MPLineChart.prototype.onLoaded = function () {
        this.nativeView.frame = CGRectMake(0, 0, this.nativeView.superview.frame.size.width, this.nativeView.superview.frame.size.height);
        _super.prototype.onLoaded.call(this);
    };
    MPLineChart.prototype.resetZoomLineChart = function () {
        this.nativeView.resetZoom();
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.itemsProperty.setNative] = function (items) {
        var lineChartData = LineChartData.new();
        console.log("items length", items.length);
        for (var i = 0; i < items.length; i++) {
            if (items[i].dataSet && items[i].dataSet.length) {
                var labelLegend = items[i].legendLabel ? items[i].legendLabel : "";
                var entries = NSMutableArray.new();
                for (var j = 0; j < items[i].dataSet.length; j++) {
                    var entrie = ChartDataEntry.new().initWithXY(items[i].dataSet[j].x, items[i].dataSet[j].y);
                    entries.addObject(entrie);
                }
                var dataset = LineChartDataSet.new().initWithValuesLabel(entries, labelLegend);
                dataset.lineColor = items[i].lineColor.ios;
                dataset.setLineColor();
                dataset.drawCircleHoleEnabled = items[i].circleHoleEnabled ? !!items[i].circleHoleEnabled : false;
                var colorCircle = NSMutableArray.new();
                if (items[i].circleColor) {
                    colorCircle.addObject(items[i].circleColor.ios);
                }
                dataset.circleColors = colorCircle;
                dataset.circleHoleRadius = 3;
                dataset.drawCirclesEnabled = items[i].circleEnable;
                dataset.highlightEnabled = false;
                if (items[i].highlighColor) {
                    dataset.highlightColor = items[i].highlighColor.ios;
                }
                if (this.showValueLabels != undefined) {
                    dataset.drawValuesEnabled = this.showValueLabels;
                }
                else {
                    dataset.drawValuesEnabled = true;
                }
                lineChartData.addDataSet(dataset);
            }
            else {
                throw new Error("items number " + i + "do not have any item");
            }
        }
        this.nativeView.lineChartData = lineChartData;
        this.nativeView.setData();
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.labelsProperty.setNative] = function (labels) {
        if (labels) {
            var formatter = ChartDefaultAxisValueFormatter.alloc().initWithBlock(function (value, axis) {
                for (var i = 0; i < labels.length; i++) {
                    if (labels[i].xAxisValue == value) {
                        return labels[i].label + '';
                    }
                }
                return "";
            });
            var xAxis = this.nativeView.xAxis;
            if (xAxis) {
                xAxis.valueFormatter = formatter;
            }
            else {
                throw new Error("xAxis in labels Property setup undefined");
            }
        }
        else {
            throw new Error("labels value undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.showLegendProperty.setNative] = function (value) {
        var legend = this.nativeView.legend;
        console.log("showLegend ", value);
        if (legend) {
            legend.enabled = value;
        }
        else {
            throw new Error("Property 'legend' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.showGridLinesProperty.setNative] = function (value) {
        var xAxis;
        var leftAxis;
        var rightAxis;
        xAxis = this.nativeView.xAxis;
        leftAxis = this.nativeView.leftAxis;
        rightAxis = this.nativeView.rightAxis;
        if (xAxis && leftAxis && rightAxis) {
            xAxis.drawGridLinesEnabled = value;
            leftAxis.drawGridLinesEnabled = value;
            rightAxis.drawGridLinesEnabled = value;
        }
        else {
            throw new Error("Property 'xAxis' or 'leftAxis' or 'rightAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.scaleEnableProperty.setNative] = function (value) {
        this.nativeView.setScaleEnabled(value);
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.descriptionTextProperty.setNative] = function (value) {
        this.nativeView.chartDescription.text = value;
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.descriptionXOffsetProperty.setNative] = function (value) {
        this.nativeView.chartDescription.xOffset = value;
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.descriptionYOffsetProperty.setNative] = function (value) {
        this.nativeView.chartDescription.yOffset = value;
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.descriptionTextColorProperty.setNative] = function (value) {
        this.nativeView.chartDescription.textColor = value.ios;
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.descriptionTextColorCssProperty.setNative] = function (value) {
        this.nativeView.chartDescription.textColor = value.ios;
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.highlightPerTapEnabledProperty.setNative] = function (value) {
        this.nativeView.highlightPerTapEnabled = value;
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.highlightPerDragEnabledProperty.setNative] = function (value) {
        this.nativeView.highlightPerDragEnabled = value;
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.xAxisGranularityProperty.setNative] = function (value) {
        var xAxis;
        xAxis = this.nativeView.xAxis;
        if (xAxis) {
            xAxis.granularity = value;
        }
        else {
            throw new Error("Property 'xAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.leftAxisGranularityProperty.setNative] = function (value) {
        var leftAxis;
        leftAxis = this.nativeView.leftAxis;
        if (leftAxis) {
            leftAxis.granularity = value;
        }
        else {
            throw new Error("Property 'leftAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.rightAxisGranularityProperty.setNative] = function (value) {
        var rightAxis;
        rightAxis = this.nativeView.rightAxis;
        if (rightAxis) {
            rightAxis.granularity = value;
        }
        else {
            throw new Error("Property  'rightAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.xAxisLabelPositionProperty.getDefault] = function () {
        return "Bottom";
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.xAxisLabelPositionProperty.setNative] = function (value) {
        var xAxis = this.nativeView.xAxis;
        if (xAxis) {
            switch (value) {
                case "Top":
                    this.nativeView.xAxis.labelPosition = 0;
                    break;
                case "Bottom":
                    this.nativeView.xAxis.labelPosition = 1;
                    break;
                case "BothSided":
                    this.nativeView.xAxis.labelPosition = 2;
                    break;
                case "TopInside":
                    this.nativeView.xAxis.labelPosition = 3;
                    break;
                case "BottomInside":
                    this.nativeView.xAxis.labelPosition = 4;
                    break;
                default:
                    console.log("Value of xAxisLabelPosition property do not exist, default value will set Bottom");
                    break;
            }
            this.nativeView.frame = CGRectMake(0, 0, this.nativeView.superview.frame.size.width, this.nativeView.superview.frame.size.height);
        }
        else {
            throw new Error("Property 'xAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.xAxisLineColorProperty.setNative] = function (value) {
        var xAxis;
        xAxis = this.nativeView.xAxis;
        if (xAxis) {
            xAxis.axisLineColor = value.ios;
        }
        else {
            throw new Error("Property  'xAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.xAxisLineColorCssProperty.setNative] = function (value) {
        var xAxis;
        xAxis = this.nativeView.xAxis;
        if (xAxis) {
            xAxis.axisLineColor = value.ios;
        }
        else {
            throw new Error("Property  'xAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.leftAxisLineColorProperty.setNative] = function (value) {
        var leftAxis;
        leftAxis = this.nativeView.leftAxis;
        if (leftAxis) {
            leftAxis.axisLineColor = value.ios;
        }
        else {
            throw new Error("Property  'leftAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.leftAxisLineColorCssProperty.setNative] = function (value) {
        var leftAxis;
        leftAxis = this.nativeView.leftAxis;
        if (leftAxis) {
            leftAxis.axisLineColor = value.ios;
        }
        else {
            throw new Error("Property  'leftAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.rightAxisLineColorProperty.setNative] = function (value) {
        var rightAxis;
        rightAxis = this.nativeView.rightAxis;
        if (rightAxis) {
            rightAxis.axisLineColor = value.ios;
        }
        else {
            throw new Error("Property  'rightAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.rightAxisLineColorCssProperty.setNative] = function (value) {
        var rightAxis;
        rightAxis = this.nativeView.rightAxis;
        if (rightAxis) {
            rightAxis.axisLineColor = value.ios;
        }
        else {
            throw new Error("Property  'rightAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.xAxisTextColorProperty.setNative] = function (value) {
        var xAxis;
        xAxis = this.nativeView.xAxis;
        if (xAxis && value) {
            xAxis.labelTextColor = value.ios;
        }
        else {
            throw new Error("Property  'xAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.xAxisTextColorCssProperty.setNative] = function (value) {
        var xAxis;
        xAxis = this.nativeView.xAxis;
        if (xAxis && value) {
            xAxis.labelTextColor = value.ios;
        }
        else {
            throw new Error("Property  'xAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.leftAxisTextColorProperty.setNative] = function (value) {
        var leftAxis;
        leftAxis = this.nativeView.leftAxis;
        if (leftAxis && value) {
            leftAxis.labelTextColor = value.ios;
        }
        else {
            throw new Error("Property  'leftAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.leftAxisTextColorCssProperty.setNative] = function (value) {
        var leftAxis;
        leftAxis = this.nativeView.leftAxis;
        if (leftAxis && value) {
            leftAxis.labelTextColor = value.ios;
        }
        else {
            throw new Error("Property  'leftAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.rightAxisTextColorProperty.setNative] = function (value) {
        var rightAxis;
        rightAxis = this.nativeView.rightAxis;
        if (rightAxis && value) {
            rightAxis.labelTextColor = value.ios;
        }
        else {
            throw new Error("Property  'rightAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.rightAxisTextColorCssProperty.setNative] = function (value) {
        var rightAxis;
        rightAxis = this.nativeView.rightAxis;
        if (rightAxis && value) {
            rightAxis.labelTextColor = value.ios;
        }
        else {
            throw new Error("Property  'rightAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.xAxisMinValueProperty.setNative] = function (value) {
        var xAxis;
        xAxis = this.nativeView.xAxis;
        if (xAxis) {
            xAxis.axisMinimum = value;
        }
        else {
            throw new Error("Property  'xAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.xAxisMaxValueProperty.setNative] = function (value) {
        var xAxis;
        xAxis = this.nativeView.xAxis;
        if (xAxis) {
            xAxis.axisMaximum = value;
        }
        else {
            throw new Error("Property  'xAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.leftAxisMinValueProperty.setNative] = function (value) {
        var leftAxis;
        leftAxis = this.nativeView.leftAxis;
        if (leftAxis) {
            leftAxis.axisMinimum = value;
        }
        else {
            throw new Error("Property  'xAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.leftAxisMaxValueProperty.setNative] = function (value) {
        var leftAxis;
        leftAxis = this.nativeView.leftAxis;
        if (leftAxis) {
            leftAxis.axisMaximum = value;
        }
        else {
            throw new Error("Property  'xAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.rightAxisMinValueProperty.setNative] = function (value) {
        var rightAxis;
        rightAxis = this.nativeView.rightAxis;
        if (rightAxis) {
            rightAxis.axisMinimum = value;
        }
        else {
            throw new Error("Property  'xAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.rightAxisMaxValueProperty.setNative] = function (value) {
        var rightAxis;
        rightAxis = this.nativeView.rightAxis;
        if (rightAxis) {
            rightAxis.axisMaximum = value;
        }
        else {
            throw new Error("Property  'xAxis' of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.leftAxisFormatterProperty.setNative] = function (formatterValue) {
        if (formatterValue) {
            var leftAxis = this.nativeView.leftAxis;
            switch (formatterValue.type) {
                case "Int":
                    var formatter = ChartDefaultAxisValueFormatter.alloc().initWithBlock(function (value, axis) {
                        if (value == 0 || value) {
                            return value.toFixed();
                        }
                        else {
                            return "";
                        }
                    });
                    leftAxis.valueFormatter = formatter;
                    break;
                case "Float":
                    var formatter = ChartDefaultAxisValueFormatter.alloc().initWithBlock(function (value, axis) {
                        if (value == 0 || value) {
                            return value.toFixed(formatterValue.numberOfDigits);
                        }
                        else {
                            return "";
                        }
                    });
                    leftAxis.valueFormatter = formatter;
                    break;
                default:
                    break;
            }
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.rightAxisFormatterProperty.setNative] = function (formatterValue) {
        if (formatterValue) {
            var rightAxis = this.nativeView.rightAxis;
            switch (formatterValue.type) {
                case "Int":
                    var formatter = ChartDefaultAxisValueFormatter.alloc().initWithBlock(function (value, axis) {
                        if (value == 0 || value) {
                            return value.toFixed();
                        }
                        else {
                            return "";
                        }
                    });
                    rightAxis.valueFormatter = formatter;
                    break;
                case "Float":
                    var formatter = ChartDefaultAxisValueFormatter.alloc().initWithBlock(function (value, axis) {
                        if (value == 0 || value) {
                            return value.toFixed(formatterValue.numberOfDigits);
                        }
                        else {
                            return "";
                        }
                    });
                    rightAxis.valueFormatter = formatter;
                    break;
                default:
                    break;
            }
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.fontProperty.setNative] = function (fontName) {
        var font;
        var familyNames = UIFont.familyNames;
        var xAxis = this.nativeView.xAxis;
        var leftAxis = this.nativeView.leftAxis;
        var rightAxis = this.nativeView.rightAxis;
        for (var i = 0; i < familyNames.count; ++i) {
            if (familyNames[i] == fontName) {
                font = fontName;
                break;
            }
            var famName = familyNames[i];
            var fontNamesForFamily = UIFont.fontNamesForFamilyName(famName);
            for (var k = 0; k < fontNamesForFamily.count; ++k) {
                if (fontName == fontNamesForFamily[k]) {
                    font = fontName;
                    break;
                }
            }
        }
        if (font) {
            if (xAxis) {
                console.log(" xAxis.labelFont ", xAxis.labelFont.fontName);
                xAxis.labelFont = UIFont.fontWithNameSize(font, xAxis.labelFont.pointSize);
            }
            if (leftAxis) {
                leftAxis.labelFont = UIFont.fontWithNameSize(font, leftAxis.labelFont.pointSize);
            }
            if (rightAxis) {
                rightAxis.labelFont = UIFont.fontWithNameSize(font, rightAxis.labelFont.pointSize);
            }
            if (this.nativeView.data) {
                var dataSets = this.nativeView.data.dataSets;
                if (dataSets) {
                    for (var i_1 = 0; i_1 < dataSets.count; i_1++) {
                        dataSets[i_1].valueFont = UIFont.fontWithNameSize(font, dataSets[i_1].valueFont.pointSize);
                    }
                }
            }
            if (this.nativeView.legend) {
                this.nativeView.legend.font = UIFont.fontWithNameSize(font, this.nativeView.legend.font.pointSize);
            }
            if (this.nativeView.description) {
                this.nativeView.chartDescription.font = UIFont.fontWithNameSize(font, this.nativeView.chartDescription.font.pointSize);
            }
        }
        else {
            throw new Error("xAxisFontProperty Font " + fontName + " Do not exist");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.showValueLabelsProperty.getDefault] = function () {
        return true;
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.showValueLabelsProperty.setNative] = function (value) {
        this.showValueLabels = value;
        if (this.nativeView.data) {
            var dataSets = this.nativeView.data.dataSets;
            if (dataSets) {
                for (var i = 0; i < dataSets.count; i++) {
                    dataSets[i].drawValuesEnabled = value;
                }
            }
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.showLeftAxisProperty.setNative] = function (value) {
        var leftAxis;
        leftAxis = this.nativeView.leftAxis;
        if (leftAxis) {
            leftAxis.enabled = value;
        }
        else {
            throw new Error("Property  'xAxis' in showLeftAxisProperty of Chart undefined");
        }
    };
    MPLineChart.prototype[nativescript_mpchart_common_1.showRightAxisProperty.setNative] = function (value) {
        var rightAxis;
        rightAxis = this.nativeView.rightAxis;
        if (rightAxis) {
            rightAxis.enabled = value;
        }
        else {
            throw new Error("Property  'xAxis' in showRightAxisProperty of Chart undefined");
        }
    };
    return MPLineChart;
}(nativescript_mpchart_common_1.MPChartBase));
exports.MPLineChart = MPLineChart;
//# sourceMappingURL=nativescript-line-chart.ios.js.map